<?php

/**
 * @file
 * Views integration for Gallery Assist module.
 */

/**
 * Implementation of hook_views_data().
 */
function gallery_assist_views_views_data() {
  $data = array();
  // Table: gallery_assist_item.
  $data['gallery_assist_item']['table']['group']  = t('Gallery Assist');
  $data['gallery_assist_item']['table']['base'] = array(
    'field' => 'nid',
    'title' => t('Gallery Assist'),
    'help' => t('"nid" the relation field between gallery_assist_item and node table.'),
  );
  // Table relation: node.
  $data['gallery_assist_item']['table']['join'] = array(
    'node' => array(
      'left_field' => 'nid',
      'field' => 'nid',
    ),
  );
  // Integer: relation reference ID.
  $data['gallery_assist_item']['nid'] = array(
    'title' => t('Gallery Assist'),
    'help' => t('"nid" the relation field between gallery_assist_item and node table.'),
    'relationship' => array(
      'base' => 'node',
      'field' => 'nid',
      'handler' => 'views_handler_relationship',
      'label' => t('Gallery Assist'),
    ),
  );
  // Integer: Gallery Assist reference ID.
  $data['gallery_assist_item']['gref'] = array(
    'title' => t('GA-Referenz'),
    'help' => t('Gallery referenz ID. Can be used for example by using php code in the view.'),
    'field' => array(
      'handler' => 'views_handler_field_numeric',
      'click sortable' => TRUE,
     ),
    'filter' => array(
      'handler' => 'views_handler_filter_numeric',
    ),
    'sort' => array(
      'handler' => 'views_handler_sort',
    ),
  );
  // Integer: gallery item id.
  $data['gallery_assist_item']['pid'] = array(
    'title' => t('Image-ID'),
    'help' => t('The pictute ID. Can be used for example by using php code in the view.'),
    'field' => array(
      'handler' => 'views_handler_field_numeric',
      'click sortable' => TRUE,
     ),
    'filter' => array(
      'handler' => 'views_handler_filter_numeric',
    ),
    'sort' => array(
      'handler' => 'views_handler_sort',
    ),
  );
  // Bolean: is cover?.
  $data['gallery_assist_item']['cover'] = array(
    'title' => t('Is Cover?'),
    'help' => t('Argument to filter the image cover.'),
    'field' => array(
      'handler' => 'views_handler_field_numeric',
      'click sortable' => TRUE,
     ),
    'filter' => array(
      'handler' => 'views_handler_filter_numeric',
    ),
    'sort' => array(
      'handler' => 'views_handler_sort',
    ),
    'argument' => array(
      'handler' => 'views_handler_argument_numeric',
    ),
  );
  // String: thumbnail path.
  $data['gallery_assist_item']['tpath'] = array(
    'title' => t('Image'),
    'help' => t('Render the found images.'),
    'field' => array(
      'handler' => 'gallery_assist_handler_field_cover',
      'click sortable' => TRUE,
    ),
    'sort' => array(
      'handler' => 'views_handler_sort',
    ),
    'filter' => array(
      'handler' => 'views_handler_filter_string',
    ),
  );

  return $data;
}

/**
 * Implementation of hook_views_data_alter().
 */
function gallery_assist_views_views_data_alter(&$data) {
  $data['gallery_assist_item']['gref'] = array(
    'group' => t('Gallery Assist'),
    'title' => t('Counter'),
    'help' => t('Render the number of images with prefix and sufix.'),
    'field' => array(
      'handler' => 'gallery_assist_handler_field_counter',
      'click sortable' => TRUE,
    ),
    'sort' => array(
      'handler' => 'views_handler_sort',
    ),
  );
  $data['gallery_assist_item']['pid'] = array(
    'group' => t('Gallery Assist'),
    'title' => t('Image data'),
    'help' => t('Render the Image title or the Image description. Needed because extra table.'),
    'field' => array(
      'handler' => 'gallery_assist_handler_field_data',
      'click sortable' => TRUE,
    ),
    'sort' => array(
      'handler' => 'views_handler_sort',
    ),
    'filter' => array(
      'handler' => 'views_handler_filter_numeric',
    ),
  );
}

/**
 * Implementation of hook_views_handlers().
 */
function gallery_assist_views_views_handlers() {
  return array(
    'info' => array(
      'path' => drupal_get_path('module', 'gallery_assist_views') . '/views',
    ),
    'handlers' => array(
      'gallery_assist_handler_field_container' => array(
        'parent' => 'views_handler_field_node',
      ),
      'gallery_assist_handler_field_counter' => array(
        'parent' => 'views_handler_field',
      ),
      'gallery_assist_handler_field_cover' => array(
        'parent' => 'views_handler_field',
      ),
      'gallery_assist_handler_field_data' => array(
        'parent' => 'views_handler_field',
      ),
    ),
  );
}

/**
 * Implementation of hook_views_plugins
 */
function gallery_assist_views_plugins() {
  global $base_path;
  return array(
    'style' => array(
      'gallery_assist_views' => array(
        'title'  => 'Gallery Assist Cover',
        'help' => t('Displays the gallery cover of Gallery Assist galleries.'),
        'handler' => 'views_plugin_style_table',
        'theme path' => drupal_get_path('module', 'gallery_assist_views') . '/views/themes',
        'theme file' => 'gallery_assist_theme.inc',
        'theme' => 'gallery_assist_display_cover',
        'uses row plugin' => TRUE,
        'uses options' => TRUE,
        'type' => 'normal',
        'no ui' => TRUE,
        'help topic' => 'gallery-assist-views',
      ),
    ),
  );
}
